@@ -4,16 +4,16 @@
  */
 import { getInjectable } from "@ogre-tools/injectable";
 import directoryForUserDataInjectable from "../../../common/app-paths/directory-for-user-data/directory-for-user-data.injectable";
-import getAbsolutePathInjectable from "../../../common/path/get-absolute-path.injectable";
+import joinPathsInjectable from "../../../common/path/join-paths.injectable";
 
 const directoryForExtensionDataInjectable = getInjectable({
   id: "directory-for-extension-data",
 
   instantiate: (di) => {
-    const getAbsolutePath = di.inject(getAbsolutePathInjectable);
+    const joinPaths = di.inject(joinPathsInjectable);
     const directoryForUserData = di.inject(directoryForUserDataInjectable);
 
-    return getAbsolutePath(directoryForUserData, "extension_data");
+    return joinPaths(directoryForUserData, "extension_data");
   },
 });
 
