@@ -3,37 +3,31 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import directoryForLensLocalStorageInjectable from "../../../../common/directory-for-lens-local-storage/directory-for-lens-local-storage.injectable";
 import { setupIpcMainHandlers } from "./setup-ipc-main-handlers";
 import loggerInjectable from "../../../../common/logger.injectable";
 import clusterManagerInjectable from "../../../cluster/manager.injectable";
-import applicationMenuItemsInjectable from "../../../menu/application-menu-items.injectable";
-import getAbsolutePathInjectable from "../../../../common/path/get-absolute-path.injectable";
 import clusterStoreInjectable from "../../../../common/cluster-store/cluster-store.injectable";
 import { onLoadOfApplicationInjectionToken } from "../../../start-main-application/runnable-tokens/on-load-of-application-injection-token";
 import operatingSystemThemeInjectable from "../../../theme/operating-system-theme.injectable";
 import catalogEntityRegistryInjectable from "../../../catalog/entity-registry.injectable";
 import askUserForFilePathsInjectable from "../../../ipc/ask-user-for-file-paths.injectable";
-import clustersThatAreBeingDeletedInjectable from "../../../cluster/are-being-deleted.injectable";
+import applicationMenuItemCompositeInjectable from "../../../../features/application-menu/main/application-menu-item-composite.injectable";
+import emitAppEventInjectable from "../../../../common/app-event-bus/emit-event.injectable";
+import createResourceApplierInjectable from "../../../resource-applier/create-resource-applier.injectable";
 
 const setupIpcMainHandlersInjectable = getInjectable({
   id: "setup-ipc-main-handlers",
 
   instantiate: (di) => {
     const logger = di.inject(loggerInjectable);
-
-    const directoryForLensLocalStorage = di.inject(
-      directoryForLensLocalStorageInjectable,
-    );
-
     const clusterManager = di.inject(clusterManagerInjectable);
-    const applicationMenuItems = di.inject(applicationMenuItemsInjectable);
-    const getAbsolutePath = di.inject(getAbsolutePathInjectable);
+    const applicationMenuItemComposite = di.inject(applicationMenuItemCompositeInjectable);
     const catalogEntityRegistry = di.inject(catalogEntityRegistryInjectable);
     const clusterStore = di.inject(clusterStoreInjectable);
     const operatingSystemTheme = di.inject(operatingSystemThemeInjectable);
     const askUserForFilePaths = di.inject(askUserForFilePathsInjectable);
-    const clustersThatAreBeingDeleted = di.inject(clustersThatAreBeingDeletedInjectable);
+    const emitAppEvent = di.inject(emitAppEventInjectable);
+    const createResourceApplier = di.inject(createResourceApplierInjectable);
 
     return {
       id: "setup-ipc-main-handlers",
@@ -41,15 +35,14 @@ const setupIpcMainHandlersInjectable = getInjectable({
         logger.debug("[APP-MAIN] initializing ipc main handlers");
 
         setupIpcMainHandlers({
-          applicationMenuItems,
-          getAbsolutePath,
-          directoryForLensLocalStorage,
+          applicationMenuItemComposite,
           clusterManager,
           catalogEntityRegistry,
           clusterStore,
           operatingSystemTheme,
           askUserForFilePaths,
-          clustersThatAreBeingDeleted,
+          emitAppEvent,
+          createResourceApplier,
         });
       },
     };
