@@ -21,7 +21,7 @@ const getHelmEnvInjectable = getInjectable({
       const result = await execHelm(["env"]);
 
       if (!result.callWasSuccessful) {
-        return { callWasSuccessful: false, error: result.error };
+        return { callWasSuccessful: false, error: result.error.stderr };
       }
 
       const lines = result.response.split(/\r?\n/); // split by new line feed
