@@ -6,17 +6,25 @@
 import type { KubeConfig } from "@kubernetes/client-node";
 import type { Cluster } from "../../common/cluster/cluster";
 import type { ClusterContextHandler } from "../context-handler/context-handler";
-import path from "path";
-import fs from "fs-extra";
 import { dumpConfigYaml } from "../../common/kube-helpers";
 import { isErrnoException } from "../../common/utils";
 import type { PartialDeep } from "type-fest";
 import type { Logger } from "../../common/logger";
+import type { JoinPaths } from "../../common/path/join-paths.injectable";
+import type { GetDirnameOfPath } from "../../common/path/get-dirname.injectable";
+import type { PathExists } from "../../common/fs/path-exists.injectable";
+import type { DeleteFile } from "../../common/fs/delete-file.injectable";
+import type { WriteFile } from "../../common/fs/write-file.injectable";
 
 export interface KubeconfigManagerDependencies {
   readonly directoryForTemp: string;
   readonly logger: Logger;
-  lensProxyPort: { get: () => number };
+  readonly lensProxyPort: { get: () => number };
+  joinPaths: JoinPaths;
+  getDirnameOfPath: GetDirnameOfPath;
+  pathExists: PathExists;
+  deleteFile: DeleteFile;
+  writeFile: WriteFile;
 }
 
 export class KubeconfigManager {
@@ -24,10 +32,9 @@ export class KubeconfigManager {
    * The path to the temp config file
    *
    * - if `string` then path
-   * - if `null` then not yet created
-   * - if `undefined` then unlinked by calling `clear()`
+   * - if `null` then not yet created or was cleared
    */
-  protected tempFilePath: string | null | undefined = null;
+  protected tempFilePath: string | null = null;
 
   protected readonly contextHandler: ClusterContextHandler;
 
@@ -40,11 +47,7 @@ export class KubeconfigManager {
    * @returns The path to the temporary kubeconfig
    */
   async getPath(): Promise<string> {
-    if (this.tempFilePath === undefined) {
-      throw new Error("kubeconfig is already unlinked");
-    }
-
-    if (this.tempFilePath === null || !(await fs.pathExists(this.tempFilePath))) {
+    if (this.tempFilePath === null || !(await this.dependencies.pathExists(this.tempFilePath))) {
       return await this.ensureFile();
     }
 
@@ -62,13 +65,13 @@ export class KubeconfigManager {
     this.dependencies.logger.info(`[KUBECONFIG-MANAGER]: Deleting temporary kubeconfig: ${this.tempFilePath}`);
 
     try {
-      await fs.unlink(this.tempFilePath);
+      await this.dependencies.deleteFile(this.tempFilePath);
     } catch (error) {
       if (isErrnoException(error) && error.code !== "ENOENT") {
         throw error;
       }
     } finally {
-      this.tempFilePath = undefined;
+      this.tempFilePath = null;
     }
   }
 
@@ -78,7 +81,7 @@ export class KubeconfigManager {
 
       return this.tempFilePath = await this.createProxyKubeconfig();
     } catch (error) {
-      throw Object.assign(new Error("Failed to creat temp config for auth-proxy"), { cause: error });
+      throw new Error(`Failed to creat temp config for auth-proxy: ${error}`);
     }
   }
 
@@ -93,7 +96,7 @@ export class KubeconfigManager {
   protected async createProxyKubeconfig(): Promise<string> {
     const { cluster } = this;
     const { contextName, id } = cluster;
-    const tempFile = path.join(
+    const tempFile = this.dependencies.joinPaths(
       this.dependencies.directoryForTemp,
       `kubeconfig-${id}`,
     );
@@ -121,8 +124,7 @@ export class KubeconfigManager {
     // write
     const configYaml = dumpConfigYaml(proxyConfig);
 
-    await fs.ensureDir(path.dirname(tempFile));
-    await fs.writeFile(tempFile, configYaml, { mode: 0o600 });
+    await this.dependencies.writeFile(tempFile, configYaml, { mode: 0o600 });
     this.dependencies.logger.debug(`[KUBECONFIG-MANAGER]: Created temp kubeconfig "${contextName}" at "${tempFile}": \n${configYaml}`);
 
     return tempFile;
