@@ -3,19 +3,21 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import appEventBusInjectable from "../../../common/app-event-bus/app-event-bus.injectable";
+import emitAppEventInjectable from "../../../common/app-event-bus/emit-event.injectable";
 import { beforeQuitOfFrontEndInjectionToken } from "../runnable-tokens/before-quit-of-front-end-injection-token";
 
 const emitCloseToEventBusInjectable = getInjectable({
   id: "emit-close-to-event-bus",
 
   instantiate: (di) => {
-    const appEventBus = di.inject(appEventBusInjectable);
+    const emitAppEvent = di.inject(emitAppEventInjectable);
 
     return {
       id: "emit-close-to-event-bus",
       run: () => {
-        appEventBus.emit({ name: "app", action: "close" });
+        emitAppEvent({ name: "app", action: "close" });
+
+        return undefined;
       },
     };
   },
