@@ -6,9 +6,8 @@
 // Move embedded kubeconfig into separate file and add reference to it to cluster settings
 // convert file path cluster icons to their base64 encoded versions
 
-import path from "path";
 import fse from "fs-extra";
-import { loadConfigFromFileSync } from "../../common/kube-helpers";
+import { loadConfigFromString } from "../../common/kube-helpers";
 import type { MigrationDeclaration } from "../helpers";
 import { migrationLog } from "../helpers";
 import type { ClusterModel } from "../../common/cluster-types";
@@ -19,6 +18,8 @@ import directoryForKubeConfigsInjectable
   from "../../common/app-paths/directory-for-kube-configs/directory-for-kube-configs.injectable";
 import getCustomKubeConfigDirectoryInjectable
   from "../../common/app-paths/get-custom-kube-config-directory/get-custom-kube-config-directory.injectable";
+import readFileSyncInjectable from "../../common/fs/read-file-sync.injectable";
+import joinPathsInjectable from "../../common/path/join-paths.injectable";
 
 interface Pre360ClusterModel extends ClusterModel {
   kubeConfig?: string;
@@ -32,6 +33,8 @@ export default {
     const userDataPath = di.inject(directoryForUserDataInjectable);
     const kubeConfigsPath = di.inject(directoryForKubeConfigsInjectable);
     const getCustomKubeConfigDirectory = di.inject(getCustomKubeConfigDirectoryInjectable);
+    const readFileSync = di.inject(readFileSyncInjectable);
+    const joinPaths = di.inject(joinPathsInjectable);
 
     const storedClusters: Pre360ClusterModel[] = store.get("clusters") ?? [];
     const migratedClusters: ClusterModel[] = [];
@@ -55,7 +58,7 @@ export default {
         fse.writeFileSync(absPath, clusterModel.kubeConfig, { encoding: "utf-8", mode: 0o600 });
 
         clusterModel.kubeConfigPath = absPath;
-        clusterModel.contextName = loadConfigFromFileSync(clusterModel.kubeConfigPath).config.getCurrentContext();
+        clusterModel.contextName = loadConfigFromString(readFileSync(absPath)).config.getCurrentContext();
         delete clusterModel.kubeConfig;
 
       } catch (error) {
@@ -71,7 +74,7 @@ export default {
         if (clusterModel.preferences?.icon) {
           migrationLog(`migrating ${clusterModel.preferences.icon} for ${clusterModel.preferences.clusterName}`);
           const iconPath = clusterModel.preferences.icon.replace("store://", "");
-          const fileData = fse.readFileSync(path.join(userDataPath, iconPath));
+          const fileData = fse.readFileSync(joinPaths(userDataPath, iconPath));
 
           clusterModel.preferences.icon = `data:;base64,${fileData.toString("base64")}`;
         } else {
