@@ -5,11 +5,20 @@
 
 import React from "react";
 import "@testing-library/jest-dom/extend-expect";
-import { render } from "@testing-library/react";
 import { Avatar } from "../avatar";
 import { Icon } from "../../icon";
+import { getDiForUnitTesting } from "../../../getDiForUnitTesting";
+import { type DiRender, renderFor } from "../../test-utils/renderFor";
 
 describe("<Avatar/>", () => {
+  let render: DiRender;
+
+  beforeEach(() => {
+    const di = getDiForUnitTesting({ doGeneralOverrides: true });
+
+    render = renderFor(di);
+  });
+
   test("renders w/o errors", () => {
     const { container } = render(<Avatar title="John Ferguson"/>);
 
