@@ -5,14 +5,13 @@
 import { getInjectable } from "@ogre-tools/injectable";
 import { resolveSystemProxyInjectionToken } from "../../../common/utils/resolve-system-proxy/resolve-system-proxy-injection-token";
 import requestFromChannelInjectable from "../channel/request-from-channel.injectable";
-import resolveSystemProxyChannelInjectable from "../../../common/utils/resolve-system-proxy/resolve-system-proxy-channel.injectable";
+import { resolveSystemProxyChannel } from "../../../common/utils/resolve-system-proxy/resolve-system-proxy-channel";
 
 const resolveSystemProxyInjectable = getInjectable({
   id: "resolve-system-proxy-for-renderer",
 
   instantiate: (di) => {
     const requestFromChannel = di.inject(requestFromChannelInjectable);
-    const resolveSystemProxyChannel = di.inject(resolveSystemProxyChannelInjectable);
 
     return async (url) => requestFromChannel(resolveSystemProxyChannel, url);
   },
